summaryrefslogtreecommitdiffstats
path: root/kdat/BackupProfileManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/BackupProfileManager.h')
-rw-r--r--kdat/BackupProfileManager.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kdat/BackupProfileManager.h b/kdat/BackupProfileManager.h
index fa6939e..418d807 100644
--- a/kdat/BackupProfileManager.h
+++ b/kdat/BackupProfileManager.h
@@ -19,8 +19,8 @@
#ifndef _BackupProfileManager_h_
#define _BackupProfileManager_h_
-#include <qdict.h>
-#include <qobject.h>
+#include <tqdict.h>
+#include <tqobject.h>
#include "BackupProfile.h"
@@ -37,13 +37,13 @@
*
* The BackupProfileManager follows the Singleton pattern.
*/
-class BackupProfileManager : public QObject {
+class BackupProfileManager : public TQObject {
Q_OBJECT
static BackupProfileManager* _instance;
- QDict<BackupProfile> _backupProfiles;
- QStringList _backupProfileNames;
+ TQDict<BackupProfile> _backupProfiles;
+ TQStringList _backupProfileNames;
BackupProfileManager();
public:
@@ -59,9 +59,9 @@ public:
/**
* Get the list of all known backup profiles.
*
* @return a QStringList containing the backup profile names.
*/
- const QStringList& getBackupProfileNames();
+ const TQStringList& getBackupProfileNames();
/**
* Retrieve the named backup profile.
@@ -69,7 +69,7 @@ public:
* @param name The name of the backup profile.
* @return A pointer to the backup profile.
*/
- BackupProfile* findBackupProfile( const QString & name );
+ BackupProfile* findBackupProfile( const TQString & name );
/**
* Add a new backup profile.
@@ -59,9 +59,9 @@ public:
* Get the list of all known backup profiles.
*
- * @return a QStringList containing the backup profile names.
+ * @return a TQStringList containing the backup profile names.
*/